@@ -32,7 +32,7 @@ public:
 	void saveProticDbMl(const QFileInfo & filename) const;
 	void saveText(const QFileInfo & filename) const;
 	void saveSvg(const QFileInfo & filename) const;
-	void saveGnumeric(const QFileInfo & filename) const;
+	void saveOds(const QFileInfo & filename) const;
 
 	int getSpotNumber(int x, int y) const;
 
