@@ -9,7 +9,12 @@
 #include <iostream>
 #include <QMenu>
 #include <QMenuBar>
+#include <QStatusBar>
+#include <QDebug>
 #include <QFileDialog>
+#include <QInputDialog>
+#include <QMessageBox>
+#include <QPrintDialog>
 #include "main_window.h"
 #include "QCimg.h"
 #include "../config.h"
@@ -53,6 +58,7 @@ MainWindow::MainWindow() {
 	if (beads_icon.exists()) {
 		setWindowIcon(QIcon(beads_icon.filePath()));
 	}
+	qDebug() << "after beads_icon";
 
 	_p_results = NULL;
 	setMenuBar(menuBar());
@@ -63,7 +69,8 @@ MainWindow::MainWindow() {
 
 	positionLabel = new QLabel;
 	positionLabel->setText("0, 0");
-	statusBar()->addWidget(positionLabel);
+    QStatusBar * p_status_bar = QMainWindow::statusBar();
+	p_status_bar->addWidget(positionLabel);
 
 	createActions();
 	createMenus();
@@ -197,7 +204,7 @@ void MainWindow::saveFile() {
 							tr("Save File"),
 							QDir::currentPath().append("/untitled.png"),
 							tr(
-									"Images *.png *.jpg (*.png *.jpg);;Text *.txt (*.txt);;Gnumeric *.gnumeric (*.gnumeric);;PROTICdbML *.xml (*.xml);;Scalable Vector Graphic *.svg (*.svg)"));
+									"Images *.png *.jpg (*.png *.jpg);;Text *.txt (*.txt);;LibreOffice *.ods (*.ods);;PROTICdbML *.xml (*.xml);;Scalable Vector Graphic *.svg (*.svg)"));
 
 	if (!fileName.isEmpty()) {
 		this->setCursor(Qt::BusyCursor);
@@ -215,8 +222,8 @@ void MainWindow::saveFile() {
 		if ((to_save.suffix() == "svg") || (to_save.suffix() == "SVG")) {
 			_p_results->saveSvg(to_save);
 		}
-		if (to_save.suffix() == "gnumeric") {
-			_p_results->saveGnumeric(to_save);
+		if (to_save.suffix() == "ods") {
+			_p_results->saveOds(to_save);
 		}
 		this->setCursor(Qt::ArrowCursor);
 	}
