@@ -2,6 +2,7 @@
 #define SPOTPROTICDBDOCUMENT_H_
 
 #include <QXmlStreamWriter>
+#include <QFile>
 
 #include "spotDocument.h"
 
@@ -22,6 +23,9 @@ protected:
 	std::vector<const spot *> _samples;
 
 	QXmlStreamWriter * _p_xml_stream;
+	
+	    QFile * _output_file;
+       QTextStream * _output_stream;
 
 };
 
